# Generated by Django 4.0.10 on 2023-08-07 14:35

# Django
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("timezones", "0003_auto_20201003_1748"),
    ]

    operations = [
        migrations.DeleteModel(
            name="AaTimezones",
        ),
    ]
